## Number of steps in solution path
ns <- 3000
Cs <- c(0.063, seq(0.07, 0.29, by=0.01), seq(0.3, 4, by=0.1))


## First extract the design matrix, and the treatment and outcome vectors
X <- as.matrix(ATEHonest::NSW[, 2:10])
d <- ATEHonest::NSW$treated
y <- ATEHonest::NSW$re78
## Compute matrix of distances between treated and control units
Amain <- diag(c(0.15, 0.6, 2.5, 2.5, 2.5, 0.5, 0.5, 0.1, 0.1))

D0 <- ATEHonest::distMat(X, Amain, method="manhattan", d)
## Alternative norm from Abadie and Imbens (2011)
D2 <- ATEHonest::distMat(X, diag(1/sqrt(diag(var(X)))), method="euclidean", d)
## Mahalanobis distance matrix for variance estimation
DM <- ATEHonest::distMat(X, chol(solve(cov(X))), method="euclidean")

filename <- paste0("output/nsw_1path_", ns, ".rda")
if (!file.exists(filename)) {
    op <- ATEHonest::ATTOptPath(y, d, D0, maxsteps=ns)
    mp <- ATEHonest::ATTMatchPath(y, d, D0, M=1:25, tol=1e-12)
    save(file=filename, op, mp)
} else {
    load(filename)
}

sigma2 <- ATEHonest:::nnvar(DM, d, y, J=2)
## Table 2
t2 <- opttable(mp, op, sigma2)

## Figures
ggthemr::ggthemr(palette = "greyscale", layout = "clear", spacing = 1,
                 text_size=10, type="inner")
options(tikzMetricPackages=c("\\usepackage{amsmath}\n",
                             "\\usepackage{amsfonts}\n",
                             "\\usetikzlibrary{calc}"))


## Plot Lineberg weights
lind <- PlotLind(mp, op, mean(sigma2))

tikzDevice::tikz("fig/nsw_Lindw.tex", width=5.7, height=3)
print(lind$f +
      ggplot2::scale_x_continuous(expand=ggplot2::expansion(mult=c(0, 0))))
dev.off()

filename <- paste0("output/nsw_1path_pe_", ns, ".rda")
oe <- pathestimate(Cs, op, sigma2, drop=TRUE, opt=TRUE)

f1 <- PlotOptpath(oe)
tikzDevice::tikz("fig/nsw_opt.tex", width=5.7, height=4)
print(f1)
dev.off()

meff <- MatchEfficiency(oe, mp, mean(sigma2), mineff=95.0)
